@@ -1,14 +1,16 @@
 #' wrapper setting the correct parameters
+#' seqinr::read.fasta for reading peptide sequences
 #'
 #' peptides which do not have protein assignment drop out
 #' @param file - fasta file
 #' @export
+#' @return list with sequences
 #' @examples
 #' library(seqinr)
-#' library(prozor)
-#' file = system.file("extdata/fgcz_contaminants_20150123.fasta.gz",package = "prozor")
+#'
+#' file = system.file("extdata/fgcz_contaminants2021_20210929.fasta.gz",package = "prozor")
 #' fasta = readPeptideFasta(file)
 #'
 readPeptideFasta <- function(file){
-  read.fasta(file = file, as.string = TRUE, seqtype="AA")
+    seqinr::read.fasta(file = file, as.string = TRUE, seqtype = "AA")
 }
