@@ -3,6 +3,7 @@
 #' @param sequence - aa sequence as string
 #' @param id uniprot id id: sp|P30443|1A01_HUMAN
 #' @param sp start position of chain numeric
+#' @return string consisting of sp,"-", length of sequnce
 #' @examples
 #' seq <- "MAVMAPRTLLLLLSGALALTQTWAGSHSMRYFFTSVSRPGR\
 #' GEPRFIAVGYVDDTQFVRFDSDAASQKMEPRAPWIEQEGPEYWDQETRN\
@@ -16,10 +17,10 @@
 #' sp <- 24
 #' makeIDUnip(seq, nam, sp)
 makeIDUnip <- function(sequence, id, sp){
-  tpos <- unlist(strsplit(id, split="\\|")) [1:2]
-  tpos <- paste(tpos, "|", collapse="", sep="")
-  sp <- paste( (sp) , "-", nchar(sequence), sep="")
-  res <- paste(tpos,  sp, sep="")
+  tpos <- unlist(strsplit(id, split = "\\|")) [seq_len(2)]
+  tpos <- paste(tpos, "|", collapse = "", sep = "")
+  sp <- paste( (sp) , "-", nchar(sequence), sep = "")
+  res <- paste(tpos,  sp, sep = "")
   return(res)
 }
 #' make id for chain in format sp|P30443|1A01_HUMANs25
@@ -27,6 +28,7 @@ makeIDUnip <- function(sequence, id, sp){
 #' @param sequence - aa sequence as string
 #' @param id uniprot id id: sp|P30443|1A01_HUMAN
 #' @param sp start position of chain numeric
+#' @return string consisting of id,"s",sp
 #' @examples
 #' seq <- "MAVMAPRTLLLLLSGALALTQTWAGSHSMRYFFTSVSRPGR\
 #' GEPRFIAVGYVDDTQFVRFDSDAASQKMEPRAPWIEQEGPEYWDQETRN\
@@ -40,16 +42,16 @@ makeIDUnip <- function(sequence, id, sp){
 #' sp <- 24
 #' makeID(seq, nam, sp)
 makeID <- function(sequence, id, sp){
-  res <- paste(id, "s", sp, sep="")
+  res <- paste(id, "s", sp, sep = "")
   return(res)
 }
 
-.makesig <- function( sequence, chainstart,  idfun=makeID ){
+.makesig <- function(sequence, chainstart,  idfun=makeID ){
   attrlist <- attributes(sequence)
   newID <- idfun(sequence , attrlist$name, chainstart)
   attrlist$Annot <- newID
   attrlist$name <- newID
-  seq <- substring(sequence , first=chainstart  )
+  seq <- substring(sequence , first = chainstart  )
   attributes(seq) <- attrlist
   return(seq)
 }
@@ -59,18 +61,19 @@ makeID <- function(sequence, id, sp){
 #' @param db uniprot fasta database as list
 #' @param signal tab delimited file with signals
 #' @param idfun function to generate id's
+#' @return list with sequences with signal peptide removed
 removeSignalPeptide <- function(db, signal, idfun=makeID){
   res <- db
   tmp2 <- as.numeric(gsub("^SIGNAL [0-9]+ ([0-9]+).*"  , "\\1", signal$Signal.peptide))
 
-  cnamessplit <- strsplit(as.character(names(db)),split="\\|")
-  protnam <-do.call("rbind",cnamessplit)
+  cnamessplit <- strsplit(as.character(names(db)),split = "\\|")
+  protnam <- Reduce(rbind,cnamessplit)
 
   stopifnot(sum(protnam[,2] == signal$Entry) == length(signal$Entry))
 
-  for( i in 1:length(tmp2)){
-    if(!is.na(tmp2[i])){
-      res[[i]] <- .makesig(db[[i]], tmp2[i] + 1,idfun=idfun  )
+  for (i in seq_len(length(tmp2)) ) {
+    if (!is.na(tmp2[i])) {
+      res[[i]] <- .makesig(db[[i]], tmp2[i] + 1,idfun = idfun  )
     }
   }
   return(res)
